@@ -1,29 +1,29 @@
-from bs4 import BeautifulSoup
-from urllib.request import urlopen
-from datetime import datetime
 from .activity import Activity
+from bs4 import BeautifulSoup
+from datetime import datetime
+import dateutil.tz
 
 
 class Post():
-    def __init__(self, home, link):
+    def __init__(self, home, entry, date):
         self.home = home
-        self.link = link
+        self.entry = entry
 
-        self.data = urlopen(self.link)
-        self.data = self.data.read()
-        self.data = BeautifulSoup(self.data)
-        self.data = str(self.data)
+        self.date = date
+        self.now = datetime.now(dateutil.tz.tzlocal())
+        self.timezone_info = self.now.tzinfo
+        self.current_date = self.date.astimezone(self.timezone_info)
+        self.formatted_date = self.current_date.strftime('%Y-%m-%d')
+        self.time = self.current_date.strftime('%Y-%m-%d-%H%M')
 
-        self.date = self.search('data-utime="', '"', self.data)
-        self.date = int(self.date)
-        self.date = datetime.fromtimestamp(self.date).strftime('%Y-%m-%d')
+        self.link = self.entry.link
 
-        self.content = self.search(
-            '<span class="userContent">', '</span>', self.data
-        )
-        print('\nPost content:\n' + self.content)
+        self.content = self.entry.content[0]['value']
+        self.content = BeautifulSoup(self.content)
+        self.content = str(self.content)
+
+        print('\nPost content (' + self.time + '):\n' + self.content)
         self.clean_content = self.content.translate(str.maketrans('', '', ':'))
-
         self.words = self.clean_content.split()
 
         self.province = ''
@@ -72,10 +72,10 @@ class Post():
 
             include = False
             for term in self.strategic_terms:
-                if sentence.find(term) != -1:
+                if self.contains(sentence.lower(), term):
                     include = True
 
-            if include == True:
+            if include:
                 if words[0].lower() in ['he', 'she', 'it', 'we', 'they']:
                     self.contents[-1] += '. ' + sentence
                 else:
@@ -92,7 +92,7 @@ class Post():
 
         answer = input(
             '\n? (If correct, press Enter. '
-            'Otherwise, enter the number of activities in this post) '
+            'Otherwise, enter the number of activities in this post, or enter "q" to finish entering posts) '
         )
 
         while True:
@@ -102,6 +102,9 @@ class Post():
                         self.home, self, self.contents[number], number
                     ))
                 break
+            if answer == 'q':
+                self.home.stop = True
+                break
             try:
                 answer = int(answer)
             except ValueError:
